<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <link rel="icon" type="image/svg+xml" href="/favicon.svg" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta
      name="description"
      content="NoETL - The Not Only ETL framework for building and running data pipelines and workflows."
    />
    <title>NoETL Dashboard</title>

    <!--
      This Font Awesome link is loaded from a CDN. For a fully bundled app,
      you could also install it via npm and import it in your JavaScript.
    -->
    <link
      rel="stylesheet"
      href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css"
      integrity="sha512-iecdLmaskl7CVkqkXNQ/ZH/XLlvWZOJyj7Yy7tcenmpD1ypASozpmT/E0iPtmFIB46ZmdtAc9eNBvH0H/ZpiBw=="
      crossorigin="anonymous"
      referrerpolicy="no-referrer"
    />
    <script type="module" crossorigin src="/assets/main.js"></script>
    <link rel="modulepreload" crossorigin href="/assets/main2.js">
    <link rel="stylesheet" crossorigin href="/assets/main2.css">
    <link rel="stylesheet" crossorigin href="/assets/main.css">
  </head>
  <body>
    <!-- The root element where the React application will be mounted. -->
    <div id="root"></div>

    <!--
      This script tag is the entry point for your React application.
      The `type="module"` attribute enables modern JavaScript modules.
      A build tool like Vite will process this file and its imports.
    -->

    <!-- Fallback content for users with JavaScript disabled. -->
    <noscript>You need to enable JavaScript to run this app.</noscript>
  </body>
</html>
